# Steal Scripts


Javascript stealth scripts are located here.

To load these scripts with playwright use `Page.addInitScript` method which executes the script on page initiation and every `goto` call.

Mostly taken from https://github.com/berstend/puppeteer-extra/tree/master/packages/puppeteer-extra-plugin-stealth/evasions